@@ -12,14 +12,14 @@ logger = get_task_logger(__name__)
 @task()
 def doReset():
     lemmas = loadLemmas()
-    lemma_job = addLemmas.chunks(lemmas,10000).group()
+    lemma_job = group(chunks(addLemmas.si(),lemmas,10000))
     wfs,spells,trans = loadWF()
-    wf_job = addWFS.chunks(wfs,10000).group()
-    spell_job = addSpells.chunks(spells,10000).group()
-    trans_job = addTrans.chunks(trans,10000).group()
-    st = group([spell_job.si(),
-                trans_job.si()])
-    res = chain(loadCats.si(), lemma_job.si(),st.si(),addRelationships.si(wfs))()
+    wf_job = group(chunks(addWFS.si(),wfs,10000))
+    spell_job = group(chunks(addSpells.si(),spells,10000))
+    trans_job = group(chunks(addTrans.si(),trans,10000))
+    st = group([spell_job,
+                trans_job])
+    res = chain(loadCats.si(), lemma_job,wf_job,spell_job,trans_job,addRelationships.si(wfs))()
     res.get()
 
 
